@@ -12,7 +12,7 @@ use Date::Calc            qw/Delta_Days/;
 use Carp                  qw/croak/;
 use Encode                qw/encode_utf8/;
 
-my $VERSION = '0.2';
+my $VERSION = '0.3';
 
 #======================================================================
 # GLOBALS
@@ -129,13 +129,15 @@ sub add_sheet {
       defined $val and length $val or next COLUMN;
 
       # choose XML attributes and inner value
-      (my $attrs, $val)
-        = looks_like_number $val             ? (""                  , $val                          )
-        : $date_regex && $val =~ $date_regex ? (qq{ s="$DATE_STYLE"}, n_days($+{y}, $+{m}, $+{d})   )
-        :                                      (qq{ t="s"}          , $self->add_shared_string($val));
+      (my $tag, my $attrs, $val)
+        = looks_like_number $val             ? (v => ""                  , $val                          )
+        : $date_regex && $val =~ $date_regex ? (v => qq{ s="$DATE_STYLE"}, n_days($+{y}, $+{m}, $+{d})   )
+        : $val =~ s/^=//                     ? (f => "",                   $val                          )
+        :                                      (v => qq{ t="s"}          , $self->add_shared_string($val));
 
       # add the new XML cell
-      push @cells, sprintf qq{<c r="%s%d"%s><v>%s</v></c>}, $col_letter, $row_num, $attrs, $val;
+      my $cell = sprintf qq{<c r="%s%d"%s><%s>%s</%s></c>}, $col_letter, $row_num, $attrs, $tag, $val, $tag;
+      push @cells, $cell;
     }
 
     # generate the row XML and add it to the sheet
@@ -170,6 +172,9 @@ sub add_sheet {
 sub add_shared_string {
   my ($self, $string) = @_;
 
+  # single quote before an initial equal sign is ignored (escaping the '=' like in Excel)
+  $string =~ s/^'=/=/;
+
   # keep a global count of how many strings are in the workbook
   $self->{n_strings_in_workbook}++;
 
@@ -488,7 +493,9 @@ Excel::ValueWriter::XLSX - generating data-only Excel workbooks in XLSX format,
 =head1 SYNOPSIS
 
   my $writer = Excel::ValueWriter::XLSX->new;
-  $writer->add_sheet($sheet_name1, $table_name1, [qw/a b/], [[1, 2], [3, 4]]);
+  $writer->add_sheet($sheet_name1, $table_name1, [qw/a b tot/], [[1, 2, '=[a]+[b]'],
+                                                                 [3, 4]
+                                                                ]);
   $writer->add_sheet($sheet_name2, $table_name2, \@headers, $row_generator);
   $writer->save_as($filename);
 
@@ -500,15 +507,10 @@ format from Perl programs is the excellent L<Excel::Writer::XLSX>
 module. That module is very rich in features, but quite costly in CPU
 and memory usage. By contrast, the present module
 L<Excel::ValueWriter::XLSX> is aimed at fast and cost-effective
-production of data-only workbooks, containing nothing but plain
-values. Such workbooks are useful in architectures where Excel is used
-merely as a local database, for example in connection with a PowerBI
-architecture.
-
-=head1 VERSION
-
-This is version 0.1, the first release.
-Until version 1.0, slight changes may occur in the API.
+production of data-only workbooks, containing nothing but plain values
+and formulas, without any formatting. Such workbooks are useful in
+architectures where Excel is used merely as a local database, for
+example in connection with a Power Pivot architecture.
 
 
 =head1 METHODS
@@ -576,8 +578,11 @@ callback function used to feed a sheet with 500 lines of 300 columns of random n
 =back
 
 Cells within a row must contain scalar values. Values that look like numbers are treated
-as numbers, string values that match the C<date_regex> are converted into numbers and
-displayed through a date format, all other strings are treated as shared strings at the
+as numbers. String values that match the C<date_regex> are converted into numbers and
+displayed through a date format. String values that start with an initial '=' are treated
+as formulas; but like in Excel, if you want regular string that starts with a '=', put a single
+quote just before the '=' -- that single quote will be removed from the string.
+Everything else is treated as a string. Strings are shared at the
 workbook level (hence a string that appears several times in the input data will be stored
 only once within the workbook).
 
